==> skrooge-0.7.2.tar.bz2: skrooge-0.7.2/tests/suite_squish/tst_report/test.py <==
import os

def main():
    source(findFile("scripts", "skrooge_functions.py"))
    initAllPlugins()
    
    type(waitForObject(":Untitled - skrooge_KTabBar"), "<Ctrl+8>")
    clickButton(waitForObject(":toolBar.kZoomIn_QToolButton"))
    clickButton(waitForObject(":toolBar.kZoomOut_QToolButton"))
    clickButton(waitForObject(":toolBar.kZoomIn_QToolButton"))
    clickButton(waitForObject(":toolBar.kZoomOriginal_QToolButton"))
    scrollTo(waitForObject(":toolBar.kZoomSlider_QSlider"), 151)
    clickButton(waitForObject(":toolBar.kZoomOriginal_QToolButton"))
    sendEvent("QWheelEvent", waitForObject(":splitter.kGraphicsView_QGraphicsView"), 363, 287, 120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":splitter.kGraphicsView_QGraphicsView"), 363, 287, 120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, 120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, 120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, 120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, 120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, 120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":splitter.kGraphicsView_QGraphicsView"), 363, 287, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":splitter.kGraphicsView_QGraphicsView"), 363, 287, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":splitter.kGraphicsView_QGraphicsView"), 363, 287, -120, 0, 2)

    snooze(1)
    
    openContextMenu(waitForObject(":splitter.kGraphicsView_QGraphicsView"), 373, 63, 0)
    activateItem(waitForObjectItem(":Untitled [modified] - skrooge_KMenu", "Antialiasing"))
    openContextMenu(waitForObject(":splitter.kGraphicsView_QGraphicsView"), 365, 82, 0)
    activateItem(waitForObjectItem(":Untitled [modified] - skrooge_KMenu", "Show tool bar"))
    openContextMenu(waitForObject(":kGraphicsView_QGraphicsLineItem"), 316, 130, 0)
    activateItem(waitForObjectItem(":Untitled [modified] - skrooge_KMenu", "Show bottom tool bar"))
    openContextMenu(waitForObject(":splitter.kGraphicsView_QGraphicsView"), 330, 157, 0)
    activateItem(waitForObjectItem(":Untitled [modified] - skrooge_KMenu", "Show limits and average"))
    openContextMenu(waitForObject(":splitter.kGraphicsView_QGraphicsView"), 346, 169, 0)
    activateItem(waitForObjectItem(":Untitled [modified] - skrooge_KMenu", "Show linear regression"))
    openContextMenu(waitForObject(":kGraphicsView_QGraphicsLineItem_2"), 371, 108, 0)
    activateItem(waitForObjectItem(":Untitled [modified] - skrooge_KMenu", "Show legend"))
    sendEvent("QWheelEvent", waitForObject(":kLines_SKGComboBox"), 30, 12, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kColumns_SKGComboBox"), 33, 8, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kMode_SKGComboBox_2"), 41, 12, -120, 0, 2)
    
    snooze(1)
        
    clickButton(waitForObject(":Representation.Graph Only_QRadioButton"))
    clickButton(waitForObject(":Representation.Table Only_QRadioButton"))
    clickButton(waitForObject(":Representation.Both_QRadioButton"))
    sendEvent("QWheelEvent", waitForObject(":Dates.kPeriod_SKGComboBox"), 166, 13, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":Dates.kInterval_SKGComboBox"), 56, 9, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kForecastCmb_SKGComboBox"), 132, 9, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kForecastCmb_SKGComboBox"), 132, 9, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kForecastCmb_SKGComboBox"), 132, 9, -120, 0, 2)

    snooze(1)
    
    sendEvent("QCloseEvent", waitForObject(":file.skg [modified] - skrooge_SKGMainPanel"))
    clickButton(waitForObject(":Question – Skrooge.Do not save_KPushButton"))

==> skrooge_0.8.1.orig.tar.bz2: skrooge-0.8.1/tests/suite_squish/tst_report/test.py <==
import os

def main():
    source(findFile("scripts", "skrooge_functions.py"))
    initAllPlugins()
    
    type(waitForObject(":Untitled - skrooge_KTabBar"), "<Ctrl+Alt+0>")
    clickButton(waitForObject(":toolBar.kZoomIn_QToolButton"))
    clickButton(waitForObject(":toolBar.kZoomOut_QToolButton"))
    clickButton(waitForObject(":toolBar.kZoomIn_QToolButton"))
    clickButton(waitForObject(":toolBar.kZoomOriginal_QToolButton"))
    scrollTo(waitForObject(":toolBar.kZoomSlider_QSlider"), 151)
    clickButton(waitForObject(":toolBar.kZoomOriginal_QToolButton"))
    sendEvent("QWheelEvent", waitForObject(":splitter.kGraphicsView_QGraphicsView"), 363, 287, 120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":splitter.kGraphicsView_QGraphicsView"), 363, 287, 120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, 120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, 120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, 120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, 120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, 120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kGraphicsView_QWidget"), 363, 287, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":splitter.kGraphicsView_QGraphicsView"), 363, 287, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":splitter.kGraphicsView_QGraphicsView"), 363, 287, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":splitter.kGraphicsView_QGraphicsView"), 363, 287, -120, 0, 2)

    snooze(1)
    
    openContextMenu(waitForObject(":splitter.kGraphicsView_QGraphicsView"), 270, 63, 0)
    activateItem(waitForObjectItem(":Untitled [modified] - skrooge_KMenu", "Antialiasing"))
    openContextMenu(waitForObject(":splitter.kGraphicsView_QGraphicsView"), 270, 82, 0)
    activateItem(waitForObjectItem(":Untitled [modified] - skrooge_KMenu", "Show tool bar"))
    openContextMenu(waitForObject(":splitter.kGraphicsView_QGraphicsView"), 270, 130, 0)
    activateItem(waitForObjectItem(":Untitled [modified] - skrooge_KMenu", "Show bottom tool bar"))
    openContextMenu(waitForObject(":splitter.kGraphicsView_QGraphicsView"), 270, 157, 0)
    activateItem(waitForObjectItem(":Untitled [modified] - skrooge_KMenu", "Show limits and average"))
    openContextMenu(waitForObject(":splitter.kGraphicsView_QGraphicsView"), 270, 169, 0)
    activateItem(waitForObjectItem(":Untitled [modified] - skrooge_KMenu", "Show linear regression"))
    openContextMenu(waitForObject(":splitter.kGraphicsView_QGraphicsView"), 270, 108, 0)
    activateItem(waitForObjectItem(":Untitled [modified] - skrooge_KMenu", "Show legend"))
    sendEvent("QWheelEvent", waitForObject(":kLines_SKGComboBox"), 30, 12, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kColumns_SKGComboBox"), 33, 8, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kMode_SKGComboBox_2"), 41, 12, -120, 0, 2)
    
    snooze(1)
        
    clickButton(waitForObject(":Representation.Graph Only_QRadioButton"))
    clickButton(waitForObject(":Representation.Table Only_QRadioButton"))
    clickButton(waitForObject(":Representation.Both_QRadioButton"))
    sendEvent("QWheelEvent", waitForObject(":Dates.kPeriod_SKGComboBox"), 166, 13, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":Dates.kInterval_SKGComboBox"), 56, 9, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kForecastCmb_SKGComboBox"), 132, 9, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kForecastCmb_SKGComboBox"), 132, 9, -120, 0, 2)
    sendEvent("QWheelEvent", waitForObject(":kForecastCmb_SKGComboBox"), 132, 9, -120, 0, 2)

    snooze(1)
    
    sendEvent("QCloseEvent", waitForObject(":file.skg [modified] - skrooge_SKGMainPanel"))
    clickButton(waitForObject(":Question – Skrooge.Do not save_KPushButton"))
